@@ -2,10 +2,6 @@
 ############ First.lib ###############
 
 .onLoad <- function(lib, pkg){
-   require(haplo.stats)
-   require(survival)
-   require(mvtnorm)
-   require(gdata)
    library.dynam("SNPassoc", pkg, lib)
 }
 
